;; Generated package description from autocrypt.el  -*- no-byte-compile: t -*-
(define-package "autocrypt" "0.4.2.0.20240410.70023" "Autocrypt implementation" '((emacs "24.3")) :commit "dc0223f11daf526621fda206b38bf06c29759c94" :authors '(("Philip Kaludercic" . "philipk@posteo.net")) :maintainer '("Philip Kaludercic" . "~pkal/public-inbox@lists.sr.ht") :keywords '("comm") :url "https://git.sr.ht/~pkal/autocrypt")
